@@ -344,7 +344,7 @@ doFindPaths o = do
     case pathsOutputFormat o of
         Unstructured -> do -- FIXME: do something about this
                            putStrLn . unlines $ map (show . ((,) =<< length)) paths
-                           putStrLn . unlines $ map (\x -> maybe (show x) show $ HashMap.lookup x i2f >>= \y -> return (x, y)) (nub (sort (concat paths)))
+                           putStrLn . unlines $ map (\x -> maybe (show x) show $ HashMap.lookup x i2f >>= \y -> return (x, pretty y)) (nub (sort (concat paths)))
         JSON -> BL.putStr . A.encode $ paf
         YAML -> B.putStr . Y.encode $ paf
     putStrLn ""
