@@ -62,7 +62,7 @@ import Options.Applicative.Extra (customExecParser, helper)
 import Options.Applicative.Types (Parser)
 
 import System.IO (Handle, hFlush, stderr, stdin, stdout, hSetBuffering, BufferMode(..))
-import System.Locale (defaultTimeLocale)
+import Data.Time.Locale.Compat (defaultTimeLocale)
 
 import Text.PrettyPrint.ANSI.Leijen (colon, green, hardline, hPutDoc, indent, linebreak, list, putDoc, red, text, yellow, (<+>), Doc)
 import Text.PrettyPrint.Free (pretty)
